@@ -29,5 +29,5 @@ pub fn run_compiler_frontend<'a>(source: &'a str) -> Vec<crate::backend::Ast<'a>
 pub fn run_highlighter<'a>(source: &'a str) -> Vec<ast::Highlight<'a>> {
     let children = parser::parse_source(source);
     let children = Node::new_fragment(children);
-    children.into_highlight_ranges(None)
+    children.into_highlight_ranges(0, None)
 }
